@@ -1,14 +1,13 @@
 #' @title PN Centrality Index
 #' @description centrality index for signed networks by Everett and Borgatti
 #'
-#' @param g igraph object. Must have a "sign" edge attribute.
+#' @param g igraph object with a sign edge attribute.
 #' @param mode character string, “out” for out-pn, “in” for in-pn or “all” for undirected networks.
 #' @return centrality scores as numeric vector.
 #' @references Everett, M. and Borgatti, S. (2014) Networks containing negative ties. *Social Networks* 38 111-120
 #' @author David Schoch
 #' @importFrom Matrix t
 #' @examples
-#' library(igraph)
 #' A <- matrix(c(0,  1,  0,  1,  0,  0,  0, -1, -1,  0,
 #'               1,  0,  1, -1,  1, -1, -1,  0,  0,  0,
 #'               0,  1,  0,  1, -1,  0,  0,  0, -1,  0,
@@ -20,17 +19,15 @@
 #'              -1,  0, -1,  0,  0,  1, -1,  1,  0,  1,
 #'               0,  0,  0,  0, -1, -1,  1,  0,  1,  0), 10, 10)
 
-#'g <- igraph::graph_from_adjacency_matrix(A,"undirected",weighted = "sign")
+#'g <- graph_from_adjacency_matrix_signed(A,"undirected")
 #'pn_index(g)
 #' @export
 
 pn_index <- function(g,mode=c("all","in","out")){
-  if (!igraph::is_igraph(g)) {
-    stop("Not a graph object")
-  }
-  if(!"sign"%in%igraph::edge_attr_names(g)){
-    stop("network does not have a sign edge attribute")
+  if (!is_signed(g)) {
+    stop("network is not a signed graph")
   }
+
   mode <- match.arg(mode,c("all","in","out"))
   if(!igraph::is.directed(g)){
     mode <- "all"
@@ -58,7 +55,7 @@ pn_index <- function(g,mode=c("all","in","out")){
 #' @title Signed Degree
 #' @description several options to calculate the signed degree of vertices
 #'
-#' @param g igraph object. Must have a "sign" edge attribute.
+#' @param g igraph object with a sign edge attribute.
 #' @param mode character string, “out” for out-degree, “in” for in-degree or “all” for undirected networks.
 #' @param type character string, “pos” or “neg” for counting positive or negative neighbors only,
 #' "ratio" for pos/(pos+neg), or "net" for pos-neg.
@@ -68,11 +65,8 @@ pn_index <- function(g,mode=c("all","in","out")){
 #' @export
 
 degree_signed <- function(g,mode=c("all","in","out"), type = c("pos","neg","ratio","net")){
-  if (!igraph::is_igraph(g)) {
-    stop("Not a graph object")
-  }
-  if(!"sign"%in%igraph::edge_attr_names(g)){
-    stop("network does not have a sign edge attribute")
+  if (!is_signed(g)) {
+    stop("network is not a signed graph")
   }
   mode <- match.arg(mode,c("all","in","out"))
   if(!igraph::is.directed(g)){
@@ -118,7 +112,7 @@ degree_signed <- function(g,mode=c("all","in","out"), type = c("pos","neg","rati
 #' @description returns the eigenvector associated with the dominant eigenvalue from the adjacency matrix.
 #' @details Note that, with negative values, the adjacency matrix may not have a dominant eigenvalue.
 #' This means it is not clear which eigenvector should be used. In addition it is possible for the adjacency matrix to have repeated eigenvalues and hence multiple linearly independent eigenvectors. In this case certain centralities can be arbitrarily assigned. The function returns an error if this is the case.
-#' @param g igraph object. Must have a "sign" edge attribute.
+#' @param g igraph object with a sign edge attribute.
 #' @param scale Logical scalar, whether to scale the result to have a maximum score of one. If no scaling is used then the result vector is the same as returned by `eigen()`.
 #' @return centrality scores as numeric vector.
 #' @references
@@ -134,21 +128,18 @@ degree_signed <- function(g,mode=c("all","in","out"), type = c("pos","neg","rati
 #' @export
 
 eigen_centrality_signed <- function(g, scale = TRUE){
-  if (!igraph::is_igraph(g)) {
-    stop("Not a graph object")
+  if (!is_signed(g)) {
+    stop("network is not a signed graph")
   }
-  if(!"sign"%in%igraph::edge_attr_names(g)){
-    stop("network does not have a sign edge attribute")
-  }
-  A <- as_adj_signed(g,sparse = TRUE)
-  sA <- eigen(A)
+
+  sA <- eigen(as_adj_signed(g))
   evals <- round(sA$values,8)
   max_evals <- which(abs(evals)==max(abs(evals)))
 
   if(length(max_evals)!=1){
     stop("no dominant eigenvalue exists")
   } else{
-    evcent <- sA$vectors[,max_evals]
+    evcent <- abs(sA$vectors[,max_evals])
   }
 
   if(scale) evcent <- evcent/max(evcent)
